# Copyright 1999-2008 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

inherit eutils
DESCRIPTION="This is a sample skeleton ebuild file"
HOMEPAGE="http://www.bluez.org"
SRC_URI="http://www.kernel.org/pub/linux/bluetooth/${P/-libs}.tar.gz"
LICENSE=""
SLOT="0"
KEYWORDS="~x86 ~amd64"
S="${WORKDIR}/bluez-4.17"

IUSE="alsa cups debug gstreamer old-daemons usb"

RDEPEND="
	alsa? ( media-libs/alsa-lib )
	gstreamer? (
		>=media-libs/gstreamer-0.10
		>=media-libs/gst-plugins-base-0.10 )
	usb? ( dev-libs/libusb )
	cups? ( net-print/cups )
	sys-fs/udev
	dev-libs/glib
	sys-apps/dbus"
DEPEND="
	sys-devel/flex
	${RDEPEND}"

src_compile() {
	econf \
		$(use_enable gstreamer) \
		$(use_enable alsa) \
		$(use_enable usb) \
		--enable-netlink \
		--enable-tools \
		--enable-bccmd \
		--enable-hid2hci \
		--enable-dfutool \
		$(use_enable old-daemons hidd) \
		$(use_enable old-daemons pand) \
		$(use_enable old-daemons dund) \
		$(use_enable cups) \
		--enable-manpages \
		--enable-configfiles \
		--disable-initscripts \
		--disable-pcmciarules \
		$(use_enable debug) \
		--localstatedir=/var

	emake || die "emake failed"
}

src_install() {
	emake DESTDIR="${D}" install || die "emake install failed"

	newinitd "${FILESDIR}/4/bluetooth-init.d" bluetooth || die
	newconfd "${FILESDIR}/4/bluetooth-conf.d" bluetooth || die

	# bug #84431
	#insinto /etc/udev/rules.d/
	#newins "${FILESDIR}/bluez-utils-3.10.1-udev.rules" 70-bluetooth.rules || die
	#newins "${S}/scripts/bluetooth.rules" 70-bluetooth-pcmcia.rules || die

	#exeinto /$(get_libdir)/udev/
	#newexe "${FILESDIR}/bluez-utils-3.10.1-udev.script" bluetooth.sh || die
	#doexe  "${S}/scripts/bluetooth_serial" || die

	insinto /etc/bluetooth
	doins input/input.conf
}

pkg_postinst() {
	#udevadm control --reload_rules && udevadm trigger

	elog
	elog "To use dial up networking you must install net-dialup/ppp."
	elog ""
	elog "Since 3.0 bluez has changed the passkey handling to use a dbus based"
	elog "API so please remember to update your /etc/bluetooth/hcid.conf."
	elog "For a password agent, there is for example net-wireless/bluez-gnome"
	elog "for gnome and net-wireless/kdebluetooth for kde."
	elog ""
	elog "Since 3.10.1 we don't install the old style daemons any more but rely"
	elog "on the new service architechture:"
	elog "  http://wiki.bluez.org/wiki/Services"
	elog ""
	elog "3.15 adds support for the audio service. See"
	elog "http://wiki.bluez.org/wiki/HOWTO/AudioDevices for configuration help."
	elog ""
	elog "Use the old-daemons use flag to get the old daemons like hidd"
	elog "installed. Please note that the init script doesn't stop the old"
	elog "daemons after you update it so it's recommended to run:"
	elog "  /etc/init.d/bluetooth stop"
	elog "before updating your configuration files or you can manually kill"
	elog "the extra daemons you previously enabled in /etc/conf.d/bluetooth."
	elog ""
	elog "If you want to use rfcomm as a normal user, you need to add the user"
	elog "to the uucp group."
	elog ""

	elog "The bluetooth service should be started automatically by udev"
	elog "when the required hardware is inserted next time."
	elog
	ewarn "On first install you need to run /etc/init.d/dbus reload or hcid"
	ewarn "will fail to start."
}
